@@ -9,6 +9,7 @@
 
 import gettext
 import os
+from typing import Optional
 
 from jinja2 import Environment, FileSystemLoader
 from jupyter_server.base.handlers import FileFindHandler, path_regex
@@ -53,13 +54,13 @@ def _jupyter_server_extension_points():
     return [{"module": "voila.server_extension"}]
 
 
-def load_config_file() -> Config:
+def load_config_file() -> Optional[Config]:
     """
     Loads voila.json and voila.py config file from current working
     directory and other Jupyter paths
     """
 
-    new_config = Config()
+    new_config = None
     base_file_name = "voila"
     config_file_paths = [*jupyter_config_path(), os.getcwd()]
 
@@ -67,6 +68,10 @@ def load_config_file() -> Config:
         py_loader = PyFileConfigLoader(filename=f"{base_file_name}.py", path=current)
         try:
             py_config = py_loader.load_config()
+
+            if new_config is None:
+                new_config = Config()
+
             new_config.merge(py_config)
         except ConfigFileNotFound:
             pass
@@ -76,6 +81,10 @@ def load_config_file() -> Config:
         )
         try:
             json_config = json_loader.load_config()
+
+            if new_config is None:
+                new_config = Config()
+
             new_config.merge(json_config)
         except ConfigFileNotFound:
             pass
@@ -88,7 +97,10 @@ def _load_jupyter_server_extension(server_app: ServerApp):
     # common configuration options between the server extension and the application
 
     voila_configuration = VoilaConfiguration(parent=server_app)
-    voila_configuration.config.merge(load_config_file())
+
+    local_config = load_config_file()
+    if local_config is not None:
+        voila_configuration.update_config(local_config)
 
     template_name = voila_configuration.template
     template_paths = collect_template_paths(["voila", "nbconvert"], template_name)
@@ -113,7 +125,9 @@ def _load_jupyter_server_extension(server_app: ServerApp):
     tree_handler_conf = {"voila_configuration": voila_configuration}
 
     themes_dir = pjoin(get_data_dir(), "themes")
-    labextensions_path = get_voila_labextensions_path()
+    labextensions_path = get_voila_labextensions_path(
+        voila_configuration.extra_labextensions_path
+    )
 
     handlers = [
         (
